@@ -31,8 +31,8 @@
  * #GstPluginFeature.
  *
  * Use the gst_device_provider_factory_find() and
- * gst_device_provider_factory_create() functions to create device
- * provider instances or use gst_device_provider_factory_make() as a
+ * gst_device_provider_factory_get() functions to create device
+ * provider instances or use gst_device_provider_factory_get_by_name() as a
  * convenient shortcut.
  *
  * Since: 1.4
@@ -275,8 +275,10 @@ gst_device_provider_factory_get (GstDeviceProviderFactory * factory)
     goto no_type;
 
   device_provider = g_atomic_pointer_get (&newfactory->provider);
-  if (device_provider)
+  if (device_provider) {
+    gst_object_unref (factory);
     return gst_object_ref (device_provider);
+  }
 
   /* create an instance of the device provider, cast so we don't assert on NULL
    * also set name as early as we can
@@ -292,8 +294,12 @@ gst_device_provider_factory_get (GstDeviceProviderFactory * factory)
    * an device provider at the same moment
    */
   oclass = GST_DEVICE_PROVIDER_GET_CLASS (device_provider);
-  if (!g_atomic_pointer_compare_and_exchange (&oclass->factory, NULL, factory))
+  if (!g_atomic_pointer_compare_and_exchange (&oclass->factory, NULL, factory)) {
     gst_object_unref (factory);
+  } else {
+    /* This ref will never be dropped as the class is never destroyed */
+    GST_OBJECT_FLAG_SET (factory, GST_OBJECT_FLAG_MAY_BE_LEAKED);
+  }
 
   gst_object_ref_sink (device_provider);
 
@@ -388,8 +394,7 @@ create_failed:
  * only be retrieved if the device provider factory is loaded, which can be
  * assured with gst_plugin_feature_load().
  *
- * Returns: the #GType for device providers managed by this factory or 0 if
- * the factory is not loaded.
+ * Returns: the #GType for device providers managed by this factory.
  *
  * Since: 1.4
  */
@@ -397,7 +402,8 @@ GType
 gst_device_provider_factory_get_device_provider_type (GstDeviceProviderFactory *
     factory)
 {
-  g_return_val_if_fail (GST_IS_DEVICE_PROVIDER_FACTORY (factory), 0);
+  g_return_val_if_fail (GST_IS_DEVICE_PROVIDER_FACTORY (factory),
+      G_TYPE_INVALID);
 
   return factory->type;
 }
@@ -463,7 +469,7 @@ gst_device_provider_factory_get_metadata_keys (GstDeviceProviderFactory *
  * gst_device_provider_factory_has_classesv:
  * @factory: a #GstDeviceProviderFactory
  * @classes: (array zero-terminated=1) (allow-none): a %NULL terminated array
- *   of klasses to match, only match if all classes are matched
+ *   of classes to match, only match if all classes are matched
  *
  * Check if @factory matches all of the given classes
  *
@@ -492,7 +498,7 @@ gst_device_provider_factory_has_classesv (GstDeviceProviderFactory * factory,
     const gchar *found;
     guint len;
 
-    if (classes[0] == '\0')
+    if (classes[0][0] == '\0')
       continue;
 
     found = strstr (klass, classes[0]);
@@ -513,7 +519,7 @@ gst_device_provider_factory_has_classesv (GstDeviceProviderFactory * factory,
 /**
  * gst_device_provider_factory_has_classes:
  * @factory: a #GstDeviceProviderFactory
- * @classes: (allow-none): a "/" separate list of klasses to match, only match
+ * @classes: (allow-none): a "/" separate list of classes to match, only match
  *     if all classes are matched
  *
  * Check if @factory matches all of the given @classes
